@@ -26,4 +26,7 @@ del hard_dependencies, dependency, missing_dependencies
 
 from .login.login import *
 from .traits.traits import *
-from .reports.reports import *
\ No newline at end of file
+from .segments.segments import *
+from .reports.reports import *
+from .traitFolders.traitFolders import *
+from .segmentFolders.segmentFolders import *
\ No newline at end of file
