@@ -11,7 +11,6 @@ import pandas as pd
 
 
 class Reports:
-## https://bank.demdex.com/portal/swagger/index.html#/Reporting%20API
 
     @classmethod
     def traits_trend(cls,
@@ -113,68 +112,6 @@ class Reports:
                  dataSourceId=None
                  ):
         ## Traits-trend reporting endpoint
-        request_url = "https://audience-manager.adobe.com/portal/api/v1/reports/traits-for-date?no-cache=true"
-        
-        ## Transform dates
-        datesThrough = int(datetime.datetime.strptime(datesThrough, "%Y-%m-%d").timestamp())*1000
-        
-        ## Gets details for just one sid
-        if sid:
-            sid_extra = Traits.get_one(sid=sid[0])[["traitRule", "traitRuleVersion", "type", "backfillStatus"]]
-        
-        ## Gets all trait IDs in datasource id
-        if dataSourceId:
-            sids = Traits.get_many(dataSourceId=dataSourceId, includeDetails=True)
-            sid = list(sids['sid'])
-            sid_extra = sids[["traitRule", "traitRuleVersion", "type", "backfillStatus"]]
-        
-        ## Runs traits get for folder ID to produce an array of trait IDs from folder ID
-        if folderId:
-            sids = Traits.get_many(folderId=folderId)
-            sid = list(sids['sid'])
-            sid_extra = sids[["traitRule", "traitRuleVersion", "type", "backfillStatus"]]
-        
-        request_data = {"date":datesThrough,
-                        "sids":[sid],
-                        "pageSize":100000,
-                        "page":0}
-
-        ## Make request 
-        general_headers = Headers.createHeaders()
-        reporting_headers = {"accept": "application/json, text/plain, */*"}
-        response = requests.post(url = request_url,
-                                headers = {**general_headers, **reporting_headers},
-                                data = request_data) 
-        ## Print error code if get request is unsuccessful
-        if response.status_code != 200:
-            print(response.content)
-        else:
-            ## Make a dataframe out of the response.json object
-            raw_data = response.content
-            columns = raw_data.decode('utf-8').replace('"','').split("\n")[0].split(",")
-            general_report = pd.DataFrame(columns=columns)
-            for i in range(1,len(sid)+1):
-                series = None
-                general_report_row = raw_data.decode('utf-8').replace('"','').split("\n")[i].split(",")
-                if len(general_report_row) > 46:
-                    trait_name = []
-                    for i in general_report_row:
-                        if ' ' in i:
-                            trait_name.append(general_report_row.index(i))
-                            general_report_row_left = general_report_row[0:3]
-                            general_report_row_mid = general_report_row[trait_name[0]:trait_name[-1]+1]
-                            general_report_row_mid = ','.join(general_report_row_mid)
-                            general_report_row_right = general_report_row[trait_name[-1]+1:]
-                            general_name = []
-                            general_name.append(general_report_row_mid)
-                            general_new = general_report_row_left + general_name + general_report_row_right
-                            try:
-                                series = pd.Series(general_new, index = general_report.columns)
-                            except:
-                                pass
-                else:
-                    series = pd.Series(general_report_row, index = general_report.columns)
-                general_report = general_report.append(series, ignore_index=True)
-        general_report_details = pd.merge(general_report, sid_extra, left_index=True, right_index=True)
-        return general_report_details
-                        
\ No newline at end of file
+        print("""General reports are not possible through the API. If you're forking this repo, you would need to build a selenium
+              script that uses a webdriver to login to the AAM UI, navigate to the 'General' reports section, and obtain
+              two values: UISESSIONCOOKIE and AAM-CSRF-Token""")
\ No newline at end of file
